﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using DlhSoft.Windows.Data;

namespace LoadChartViewMouseEventHandlingSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
        }

        private void LoadChartView_PreviewMouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            // Ensure that the absolute position is within LoadChartView.
            Point absolutePosition = e.GetPosition(LoadChartView);
            if (absolutePosition.X < 0 || absolutePosition.X >= LoadChartView.ActualWidth || absolutePosition.Y < 0 || absolutePosition.Y >= LoadChartView.ActualHeight)
                return;

            // Get mouse event original source element and data context.
            FrameworkElement element = e.OriginalSource as FrameworkElement;
            if (element == null)
                return;
            object dataContext = element.DataContext;
            if (!(element is Panel) && dataContext == null)
                return;

            StringBuilder informationBuilder = new StringBuilder();

            // Get position information.
            Point position = e.GetPosition(LoadChartView.BaseItemsControl);
            informationBuilder.Append("Position: ");
            if (position.Y >= 0)
                informationBuilder.AppendLine(string.Format("Load Chart (X = {0:0.00}; Y = {1:0.00})", position.X, position.Y));
            else
                informationBuilder.AppendLine(string.Format("Scale (X = {0:0.00})", position.X));

            // Get resource area information.
            Resource resourceArea = LoadChartView.GetResourceAt(position.Y);
            if (resourceArea != null)
                informationBuilder.AppendLine(string.Format("Resource area: ({0})", resourceArea.Content));

            // Get date and time information.
            DateTime dateTime = LoadChartView.GetDateTime(position.X);
            informationBuilder.AppendLine(string.Format("Date and time: {0:g}", dateTime));

            string information = informationBuilder.ToString();
            MessageBox.Show(information, Title, MessageBoxButton.OK, MessageBoxImage.Information);
        }
    }
}
